package cz.muni.sutralog.ui.list

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import cz.muni.sutralog.databinding.RockItemListBinding
import cz.muni.sutralog.data.RockPresentableListItem

class RockAdapter(
    private val onItemClick: (RockPresentableListItem) -> Unit,
) : RecyclerView.Adapter<RockViewHolder>(), Filterable {

    private var listItems: MutableList<RockPresentableListItem> = mutableListOf()
    private var fullListItems: MutableList<RockPresentableListItem> = mutableListOf()
    private var rockFilter : Filter = object: Filter(){
        override fun performFiltering(constraint: CharSequence?): FilterResults {
            val filteredList = mutableListOf<RockPresentableListItem>()

            if (constraint == null || constraint.length == 0){
                filteredList.addAll(fullListItems)
            } else {
                val filterString: String = constraint.toString().lowercase().trim()

                for ( rock in fullListItems ){
                    if(rock.name.lowercase().contains(filterString)){
                        filteredList.add(rock)
                    }
                }
            }
            val results = FilterResults()
            results.values = filteredList

            return results
        }

        override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
            listItems.clear()
            listItems.addAll(results?.values as Collection<RockPresentableListItem>)
            notifyDataSetChanged()
        }

    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RockViewHolder {
        val binding = RockItemListBinding.inflate(LayoutInflater.from(parent.context), parent, false)
        return RockViewHolder(binding)
    }

    override fun onBindViewHolder(holder: RockViewHolder, position: Int) {
        holder.bind(listItems[position], onItemClick)
    }

    fun submitList(newListItems: List<RockPresentableListItem>) {
        fullListItems = newListItems.toMutableList()
        listItems = fullListItems.toMutableList()
        notifyDataSetChanged()
    }

    fun removeItem(position: Int) {
        listItems.removeAt(position)
        notifyItemRemoved(position)
    }


    override fun getItemCount(): Int = listItems.size
    override fun getFilter(): Filter {
        return rockFilter
    }
}
