package cz.muni.sutralog.ui.list

import android.os.Bundle
import android.view.LayoutInflater
import android.view.MenuItem
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.appcompat.widget.SearchView
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import cz.muni.sutralog.R
import cz.muni.sutralog.databinding.RocksListBinding
import cz.muni.sutralog.repository.RockRepository


class RockListFragment : Fragment() {

    private lateinit var binding: RocksListBinding

    private val rockRepository: RockRepository by lazy {
        RockRepository()
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = RocksListBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val adapter = RockAdapter(
            onItemClick = {
                findNavController()
                    .navigate(RockListFragmentDirections
                        .actionRockListToRockDetail())
            },
        )
        val searchItem = binding.toolbar.menu.findItem(R.id.search)
        val searchView = searchItem.actionView as SearchView

        searchView.setOnQueryTextListener(object : SearchView.OnQueryTextListener{
            override fun onQueryTextSubmit(query: String?): Boolean {
                return false
            }

            override fun onQueryTextChange(newText: String?): Boolean {
                adapter.filter.filter(newText)
                return false
            }
        })

        binding.toolbar.title = "Category name"
        binding.toolbar.setOnMenuItemClickListener {
            when (it.itemId) {
                R.id.filter -> Toast.makeText(context ,"Filter clicked", Toast.LENGTH_SHORT).show()
            }
            true
        }

        binding.toolbar.setNavigationOnClickListener{
            findNavController().navigateUp()
        }

        binding.recyclerView.adapter = adapter
        adapter.submitList(rockRepository.getMockedData(100))
    }
}